<?php if(!defined('BASEPATH')) exit('No direct script access allowed');
class Login extends CI_Controller
{
    /**
     * Constructo de ls clase del controlador
     */
    public function __construct()
    {
        parent::__construct();
        $this->load->model('login_model');
    }

    /**
     * Index del controlador.
     */
    public function index()
    {
        $this->verificarLogueo();
    }
    
    
    function verificarLogueo()
    {
        $isLoggedIn = $this->session->userdata('isLoggedIn');  
        if(!isset($isLoggedIn) || $isLoggedIn != TRUE)
        {
            $this->load->view('login');
        }
        else
        {
            redirect('/dashboard');
        }
    }
    
    
    /**
     * Funcion para el logueo de usuarios
     */
    public function loguearse()
    {
        $this->load->library('form_validation');
        
        $this->form_validation->set_rules('email', 'Email', 'required|valid_email|max_length[128]|trim');
        $this->form_validation->set_rules('password', 'Password', 'required|max_length[100]');
        
        if($this->form_validation->run() == FALSE)
        {
            $this->index();
        }
        else
        {
            $email = strtolower($this->security->xss_clean($this->input->post('email')));
            $password = $this->input->post('password');
            
            $result = $this->login_model->loguearse($email, $password);
            
            if(!empty($result))
            {
                $sessionArray = array('userId'=>$result->id,                    
                                        'tipoUserId'=>$result->id,
                                        'tipoUserName'=>$result->tipo,
                                        'name'=>$result->nombre_completo,
                                        'isLoggedIn' => TRUE
                                );
                $this->session->set_userdata($sessionArray);
                unset($sessionArray['userId'], $sessionArray['isLoggedIn']);
                redirect('/dashboard');
            }
            else
            {
                $this->session->set_flashdata('error', 'Correo o password incorrectos');
                $this->index();
            }
        }
    }

    


    public function recuperarPassword()
    {
        $isLoggedIn = $this->session->userdata('isLoggedIn');
        
        if(!isset($isLoggedIn) || $isLoggedIn != TRUE)
        {
            $this->load->view('recuperarPassword');
        }
        else
        {
            redirect('/dashboard');
        }
    }
    
    

    function resetearPassword()
    {
        $status = '';        
        $this->load->library('form_validation');
        $this->form_validation->set_rules('login_email','Email','trim|required|valid_email');
        if($this->form_validation->run() == FALSE){
            $this->recuperarPassword();
        }
        else { 
            $email = strtolower($this->security->xss_clean($this->input->post('login_email')));
            if($this->login_model->verificarExisteEmail($email)){
                $userInfo = $this->login_model->obtenerInfoUsuarioPorEmail($email);
                if(!empty($userInfo)){
                    $data1["name"] = $userInfo->nombre_completo;
                    $data1["email"] = $userInfo->email;
                    $data1["message"] = "Password recuperada";
                }
                $sendStatus = resetPasswordEmail($data1);
                if($sendStatus){
                    $status = "send";
                    setFlashData($status, "Se envio un correo a su email, por favor revise su bandeja de entrada.");
                } else {
                    $status = "notsend";
                    setFlashData($status, "No se pudo enviar el mensaje, intente de nuevo.");
                }
            }else{
                $status = 'invalid';
                setFlashData($status, "El usuario se encuentra fuera de servicio.");
            }
            redirect('/recuperarPassword');
        }
    }
}

?>